@@ -88,7 +88,7 @@ where
             sealed,
             keys,
         };
-        tracing::debug!(
+        tracing::trace!(
             "leaf created count={} bytes={} sealed={}",
             index.keys.count(),
             index.value_bytes,
@@ -142,7 +142,7 @@ where
             children.push(child);
         }
         let index = self.new_branch(&children, stream, mode)?;
-        tracing::debug!(
+        tracing::trace!(
             "branch created count={} value_bytes={} key_bytes={} sealed={}",
             index.summaries.count(),
             index.value_bytes,
@@ -196,11 +196,10 @@ where
         let summaries = children
             .iter()
             .map(|child| child.summarize())
-            .collect::<Vec<_>>();
+            .collect::<T::SummarySeq>();
         let value_bytes = children.iter().map(|x| x.value_bytes()).sum();
-        let sealed = stream.config().branch_sealed(&children, level);
-        let summaries: T::SummarySeq = summaries.into_iter().collect();
-        let (link, encoded_children_len) = self.persist_branch(&children, stream)?;
+        let sealed = stream.config().branch_sealed(children, level);
+        let (link, encoded_children_len) = self.persist_branch(children, stream)?;
         let key_bytes = children.iter().map(|x| x.key_bytes()).sum::<u64>() + encoded_children_len;
         Ok(BranchIndex {
             level,
@@ -290,7 +289,7 @@ where
         from: &mut iter::Peekable<impl Iterator<Item = (T::Key, V)> + Send>,
         stream: &mut StreamBuilderState,
     ) -> Result<Index<T>> {
-        tracing::debug!(
+        tracing::trace!(
             "extend {} {} {} {}",
             index.level(),
             index.key_bytes(),
@@ -303,14 +302,14 @@ where
         let secrets = stream.secrets().clone();
         Ok(match self.node_info(&secrets, index) {
             NodeInfo::Leaf(index, leaf) => {
-                tracing::debug!("extending existing leaf");
+                tracing::trace!("extending existing leaf");
                 let leaf = leaf.load()?;
                 let keys = index.keys.clone();
                 self.extend_leaf(leaf.as_ref().compressed(), Some(keys), from, stream)?
                     .into()
             }
             NodeInfo::Branch(index, branch) => {
-                tracing::debug!("extending existing branch");
+                tracing::trace!("extending existing branch");
                 let branch = branch.load_cached()?;
                 let mut children = branch.children.to_vec();
                 if let Some(last_child) = children.last_mut() {
@@ -358,7 +357,7 @@ where
         let _timer = prom::BRANCH_STORE_HIST.start_timer();
         let level = stream.config().zstd_level;
         let key = *stream.index_key();
-        let cbor = serialize_compressed(&key, nonce::<T>(), &mut stream.offset, &items, level)?;
+        let cbor = serialize_compressed(&key, nonce::<T>(), &mut stream.offset, items, level)?;
         let len = cbor.len() as u64;
         Ok((self.put_block(cbor)?, len))
     }
