@@ -12,7 +12,6 @@ use anyhow::Result;
 use core::fmt;
 use futures::prelude::*;
 use std::{collections::BTreeMap, iter, marker::PhantomData, usize};
-use tracing::*;
 
 #[derive(Clone)]
 pub struct Tree<T: TreeTypes, V>(Option<(Index<T>, Secrets, u64)>, PhantomData<V>);
@@ -229,7 +228,7 @@ impl<T: TreeTypes, R: ReadOnlyStore<T::Link>> Forest<T, R> {
             let mut cur = next_id;
             for x in branch.children.iter() {
                 let (mut e, mut n) =
-                    self.dump_graph0(secrets, Some(next_id), cur + 1, &x, f.clone())?;
+                    self.dump_graph0(secrets, Some(next_id), cur + 1, x, f.clone())?;
                 cur += n.len();
                 edges.append(&mut e);
                 nodes.append(&mut n);
@@ -292,7 +291,7 @@ impl<T: TreeTypes, R: ReadOnlyStore<T::Link>> Forest<T, R> {
 
     pub fn is_packed<V>(&self, tree: &Tree<T, V>) -> Result<bool> {
         if let Some((root, secrets, _)) = &tree.0 {
-            self.is_packed0(secrets, &root)
+            self.is_packed0(secrets, root)
         } else {
             Ok(true)
         }
@@ -303,7 +302,7 @@ impl<T: TreeTypes, R: ReadOnlyStore<T::Link>> Forest<T, R> {
         if !msgs.is_empty() {
             let invariants = msgs.join(",");
             for msg in msgs {
-                error!("Invariant failed: {}", msg);
+                tracing::error!("Invariant failed: {}", msg);
             }
             panic!("assert_invariants failed {}", invariants);
         }
